pub struct MH160DeviceInputChannelConfig {
pub id: MH160ChannelIdNoSync,
pub edge_trigger_level: i32,
pub edge_trigger: Edge,
pub offset: i32,
}Fields
id: MH160ChannelIdNoSyncThe channel ID, corresponding to the channel ID numbers on the MultiHarp’s interface panel. The ID must be greater than or equal to 1. 0 is reserved for the sync channel.
Internally, the MultiHarp software counts channel IDs from zero and does not assign an ID to the sync channel.
edge_trigger_level: i32edge_trigger: Edgeoffset: i32Trait Implementations
Sourceimpl Clone for MH160DeviceInputChannelConfig
impl Clone for MH160DeviceInputChannelConfig
Sourcefn clone(&self) -> MH160DeviceInputChannelConfig
fn clone(&self) -> MH160DeviceInputChannelConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for MH160DeviceInputChannelConfig
impl<'de> Deserialize<'de> for MH160DeviceInputChannelConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for MH160DeviceInputChannelConfig
impl PartialEq for MH160DeviceInputChannelConfig
Sourcefn eq(&self, other: &MH160DeviceInputChannelConfig) -> bool
fn eq(&self, other: &MH160DeviceInputChannelConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MH160DeviceInputChannelConfig