Module meta

Module meta 

Definitions needed by both impl and stub.

Many of these values are derived from mhdefin.h, which is bundled with the MultiHarp driver release. The values are copied here to avoid a hard dependency on downloading the proprietary MultiHarp shared library when using this library on non-x64 platforms or with non-MultiHarp systems.

The original constant names from mhdefin.h are preserved as comments when they have been changed; some comments are also from mhdefin.h.

Modules

event_filter
Values related to event filtering. Names of simple constants are the same as in mhdefin.h when values are defined there.

Structs

Features
Represent the bitmask returned from MH_GetFeatures. Names (minus FEATURE_ prefix) and comments from mhdefin.h.
FilteredRates
MH160InternalChannelId
The channel ID corresponding to the internal representation used in the official mhlib library. The ID must be greater than or equal to 0. The sync channel cannot be represented in this scheme.

Enums

Edge
MeasurementControl
Mode
RefSource

Constants

CHANNELS_PER_ROW
Not from mhdefin.h. However, the MHLib manual strongly implies that all rows have 8 channels; the bitmasking used when configuring the event filter is described in these terms.
MAX_INPUT_CHANNEL
Not from mhdefin.h. However, MultiHarp 160 specifications indicate that up to 64 channels are supported.
TTREADMAX
Number of event records that can be read by MH_ReadFiFo. The buffer must provide space for this number of dwords (32-bit unsigned integers).

Traits

MhlibWrapper