join_and_collect_thread_errors

Function join_and_collect_thread_errors 

pub fn join_and_collect_thread_errors(
    handles: Vec<JoinHandle<Result<()>>>,
) -> Result<()>
Utility function for keeping track of errors that originate in worker threads.

Panics

Panics in threads joined by this function will cause panics here.