pub struct MH160ChannelIdNoSync(/* private fields */);Expand description
The channel ID, corresponding to the channel ID numbers on the MultiHarp’s interface panel. The ID must be greater than or equal to 1.
Although the sync channel can be used as an ordinary channel when in T2 mode, it is not possible to represent it using this type. Use MH160ChannelIdZeroIsSync when the sync channel should be representable as an ordinary channel.
Internally, the MultiHarp software counts channel IDs from zero and does not assign an ID to the sync channel. Lower-level APIs which require that internal representation should use MH160InternalChannelId.
Implementations